@@ -32,9 +32,7 @@ class lfnc(object):
 
         return self.data.getncattr(attr)
 
-    def to_xarray(
-        self, vars: Optional[list[str]] = None, chunk_size: Optional[int] = 10
-    ):
+    def to_xarray(self, vars=None, chunk_size=10):
 
         x_var = "x_distance" if "x_distance" in self.vars else "x"
         y_var = "y_distance" if "y_distance" in self.vars else "y"
